@@ -103,7 +103,10 @@ mod tests {
         assert_eq!(fmt.to_string(), "No battery detected.".to_owned());
 
         fmt.set_percentage(50);
-        assert_eq!(fmt.to_string(), "Percentage: 50%\nState: Unknown".to_owned());
+        assert_eq!(
+            fmt.to_string(),
+            "Percentage: 50%\nState: Unknown".to_owned()
+        );
 
         fmt.set_state(BatteryState::Charging);
         assert_eq!(
