@@ -2,6 +2,7 @@
 
 mod config;
 mod fmt;
+
 mod helpers;
 mod icon;
 mod notifier;
@@ -92,11 +93,10 @@ fn main() {
             }
         }
 
-        if icon.theme.is_some() {
-            match icon.find_icon() {
-                Ok(path) => notifier.icon = path,
-                Err(e) => eprintln!("{}", e),
-            }
+        match (icon.find_icon(), use_icons) {
+            (Ok(path), true) => notifier.icon = path,
+            (Err(e), true) => eprintln!("{}", e),
+            _ => (),
         }
 
         if let Some(timeout) = config.timeout {
